# Field

A Field object stores the non-propagating data of a field as well as a number of instances of the corresponding FieldState object. The FieldState object stores the propagating data of the field in a single step. A specific type of Field object and a specific type of FieldState object are designed for each type of predefined field. Instances of the FieldState object are created and deleted internally by its corresponding Field object.

## Create fields

```{eval-rst}
.. autoclass:: abaqus.Field.FieldModel.FieldModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### Field

```{eval-rst}
.. autoclass:: abaqus.Field.Field.Field
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AnalyticalField

```{eval-rst}
.. autoclass:: abaqus.Field.AnalyticalField.AnalyticalField
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DataTable

```{eval-rst}
.. autoclass:: abaqus.Field.DataTable.DataTable
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DataTableArray

```{eval-rst}
.. autoclass:: abaqus.Field.DataTableArray.DataTableArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DiscreteField

```{eval-rst}
.. autoclass:: abaqus.Field.DiscreteField.DiscreteField
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ExpressionField

```{eval-rst}
.. autoclass:: abaqus.Field.ExpressionField.ExpressionField
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MappedField

```{eval-rst}
.. autoclass:: abaqus.Field.MappedField.MappedField
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbMeshRegionData

```{eval-rst}
.. autoclass:: abaqus.Field.OdbMeshRegionData.OdbMeshRegionData
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
